@@ -66,19 +66,32 @@ async def test_futures_funding_rate(futuresClientAsync):
     await futuresClientAsync.futures_funding_rate()
 
 
-@pytest.mark.skip(reason="Not implemented")
+@pytest.mark.skip(reason="No Sandbox Environment to test")
 async def test_futures_top_longshort_account_ratio(futuresClientAsync):
-    await futuresClientAsync.futures_top_longshort_account_ratio()
+    await futuresClientAsync.futures_top_longshort_account_ratio(
+        symbol="BTCUSDT", period="5m"
+    )
 
 
-@pytest.mark.skip(reason="Not implemented")
+@pytest.mark.skip(reason="No Sandbox Environment to test")
 async def test_futures_top_longshort_position_ratio(futuresClientAsync):
-    await futuresClientAsync.futures_top_longshort_position_ratio()
+    await futuresClientAsync.futures_top_longshort_position_ratio(
+        symbol="BTCUSDT", period="5m"
+    )
 
 
-@pytest.mark.skip(reason="Not implemented")
+@pytest.mark.skip(reason="No Sandbox Environment to test")
 async def test_futures_global_longshort_ratio(futuresClientAsync):
-    await futuresClientAsync.futures_global_longshort_ratio()
+    await futuresClientAsync.futures_global_longshort_ratio(
+        symbol="BTCUSDT", period="5m"
+    )
+
+
+@pytest.mark.skip(reason="No Sandbox Environment to test")
+async def test_futures_taker_longshort_ratio(futuresClientAsync):
+    await futuresClientAsync.futures_taker_longshort_ratio(
+        symbol="BTCUSDT", period="5m"
+    )
 
 
 async def test_futures_ticker(futuresClientAsync):
@@ -93,6 +106,10 @@ async def test_futures_orderbook_ticker(futuresClientAsync):
     await futuresClientAsync.futures_orderbook_ticker()
 
 
+async def test_futures_index_index_price_constituents(futuresClientAsync):
+    await futuresClientAsync.futures_index_price_constituents(symbol="BTCUSD")
+
+
 async def test_futures_liquidation_orders(futuresClientAsync):
     await futuresClientAsync.futures_liquidation_orders()
 
@@ -117,9 +134,9 @@ async def test_futures_index_info(futuresClientAsync):
     await futuresClientAsync.futures_index_info()
 
 
-@pytest.mark.skip(reason="Not implemented")
+@pytest.mark.skip(reason="No Sandbox Environment to test")
 async def test_futures_open_interest_hist(futuresClientAsync):
-    await futuresClientAsync.futures_open_interest_hist(symbol="BTCUSDT")
+    await futuresClientAsync.futures_open_interest_hist(symbol="BTCUSDT", period="5m")
 
 
 async def test_futures_leverage_bracket(futuresClientAsync):
@@ -444,6 +461,10 @@ async def test_futures_coin_orderbook_ticker(futuresClientAsync):
     await futuresClientAsync.futures_coin_orderbook_ticker()
 
 
+async def test_futures_coin_index_index_price_constituents(futuresClientAsync):
+    await futuresClientAsync.futures_coin_index_price_constituents(symbol="BTCUSD")
+
+
 @pytest.mark.skip(reason="Not implemented")
 async def test_futures_coin_liquidation_orders(futuresClientAsync):
     await futuresClientAsync.futures_coin_liquidation_orders()
